@@ -188,3 +188,7 @@ def make_list(obj:any) -> list:
     if isinstance(obj, list):
         return obj
     return [obj]
+
+def make_list_it(obj=None):
+    obj = make_list(obj or [])
+    return obj
