@@ -1,6 +1,7 @@
 import logging
 import os
 import inspect
+from flask import jsonify
 from .path_utils import mkdirs
 from logging.handlers import RotatingFileHandler
 from .abstract_classes import SingletonMeta
@@ -141,7 +142,12 @@ def get_logger_callable(logger, level="info"):
     else:
         return None
 
-
+def get_caller_info():
+    caller_idx = _find_caller_frame_index()
+    stack = inspect.stack()
+    caller_frame = stack[caller_idx]
+    caller_path = caller_frame.filename
+    return caller_path,caller_frame
 def print_or_log(message, logger=True, level="info"):
     """
     Print or log a message. If logger=True, find the first caller outside this module
@@ -149,10 +155,7 @@ def print_or_log(message, logger=True, level="info"):
     stacklevel that points directly at that same caller.
     """
     # 1) Find the first frame index outside logging_utils (and also outside the logging stdlib).
-    caller_idx = _find_caller_frame_index()
-    stack = inspect.stack()
-    caller_frame = stack[caller_idx]
-    caller_path = caller_frame.filename
+
     # e.g. "/home/joe/project/app/routes.py"
     bpName = os.path.splitext(os.path.basename(caller_path))[0]
     del caller_frame
@@ -175,3 +178,64 @@ def print_or_log(message, logger=True, level="info"):
         #   - stacklevel=caller_idx+1 => pathname points exactly to stack[caller_idx].filename
     else:
         print(message)
+
+def initialize_call_log(value=None,
+                        data=None,
+                        logMsg=None,
+                        log_level=None):
+    """
+    Inspect the stack to find the first caller *outside* this module,
+    then log its function name and file path.
+    """
+    # Grab the current stack
+    stack = inspect.stack()
+    caller_name = "<unknown>"
+    caller_path = "<unknown>"
+    log_level = log_level or 'info'
+    try:
+        # Starting at index=1 to skip initialize_call_log itself
+        for frame_info in stack[1:]:
+            modname = frame_info.frame.f_globals.get("__name__", "")
+            # Skip over frames in your logging modules:
+            if not modname.startswith("abstract_utilities.log_utils") \
+               and not modname.startswith("abstract_flask.request_utils") \
+               and not modname.startswith("logging"):
+                caller_name = frame_info.function
+                caller_path = frame_info.filename
+                break
+    finally:
+        # Avoid reference cycles
+        del stack
+
+    logMsg = logMsg or "initializing"
+    full_message = (
+        f"{logMsg}\n"
+        f"calling_function: {caller_name}\n"
+        f"path: {caller_path}\n"
+        f"data: {data}"
+    )
+
+    print_or_log(full_message,level=log_level)
+    
+def get_json_call_response(value, status_code, data=None,logMsg=None,callLog = False):
+    response_body = {}
+    if status_code == 200:
+        response_body["success"] = True
+        response_body["result"] = value
+        logMsg = logMsg or "success"
+        if callLog:
+            initialize_call_log(value=value,
+                            data=data,
+                            logMsg=logMsg,
+                            log_level='info')
+    else:
+        response_body["success"] = False
+        response_body["error"] = value
+        logMsg = logMsg or f"ERROR: {logMsg}"
+        initialize_call_log(value=value,
+                            data=data,
+                            logMsg=logMsg,
+                            log_level='error')
+    return jsonify(response_body), status_code
+
+
